measuretools.pad_measures_in_expr_with_rests
============================================

.. autofunction:: abjad.tools.measuretools.pad_measures_in_expr_with_rests.pad_measures_in_expr_with_rests
   :noindex:
